=========
Changelog
=========

0.5.3  (2019-02-25)
-------------------

* Add IoTLWrapper

0.5.0  (2019-02-19)
-------------------

* Each data point gets a random guid.
* Add support for distributed tracing.
* Read JSON configuration.
* Migrate to gmqtt, drop use of python-mqtt.

0.2.3  (2018-11-12)
-------------------

* Pass connection options to cloudant data storage
* Pass connection options to watson connector
* Modify how I write to the local storage
* Add test for data point
* Add test for sign & verify
* Custom (Integrated Encryption Scheme) IES encrypt/decrypt
* Bitwise permission checking

0.1.10 (2018-10-01)
-------------------

* Add connector
* Update model
* Add various data source utilities

0.1.1 (2018-10-01)
------------------

* Add common model files

0.1.0 (2018-09-28)
------------------

* First release on GitLab.
